@@ -2,15 +2,44 @@
 Initialize plugins for the CLI
 """
 import sys
+from argparse import ArgumentParser
 from importlib import import_module
 from os import listdir
 from os.path import dirname
+from pathlib import Path
 
 from linodecli.cli import CLI
+from linodecli.helpers import register_args_shared
+
+this_file = Path(__file__)
+reserved_files = {this_file}
+
+
+def is_single_file_plugin(f: Path):
+    """
+    Determine if the file is a single-file plugin.
+    """
+    return f.suffix == ".py"
+
+
+def is_module_plugin(f: Path):
+    """
+    Determine if the file is a module (directory) based plugin.
+    """
+    return f.is_dir() and f.name[:1] != "_"
+
+
+def is_plugin(f: Path):
+    """
+    Determine if the file is a linode-cli plugin.
+    """
+    if f in reserved_files:
+        return False
+    return is_module_plugin(f) or is_single_file_plugin(f)
+
 
-_available_files = listdir(dirname(__file__))
 available_local = [
-    f[:-3] for f in _available_files if f.endswith(".py") and f != "__init__.py"
+    f.stem for f in Path.iterdir(this_file.parent) if is_plugin(f)
 ]
 
 
@@ -72,3 +101,15 @@ class PluginContext:  # pylint: disable=too-few-public-methods
         """
         self.token = token
         self.client = client
+
+
+def inherit_plugin_args(parser: ArgumentParser):
+    """
+    This function allows plugin-defined ArgumentParsers to inherit
+    certain CLI configuration arguments (`--as-user`, etc.).
+
+    These arguments will be automatically applied to the CLI instance
+    provided in the PluginContext object.
+    """
+
+    return register_args_shared(parser)
